@@ -8,7 +8,7 @@
 #include "config.h"
 
 #ifndef lint
-static const char revid[] = "$Id: lock_region.c,v 1.4 2000/06/28 16:47:02 loic Exp $";
+static const char revid[] = "$Id: lock_region.c,v 1.5 2008/06/04 15:01:40 sebdiaz Exp $";
 #endif /* not lint */
 
 #ifndef NO_SYSTEM_INCLUDES
@@ -31,11 +31,13 @@ static const char revid[] = "$Id: lock_region.c,v 1.4 2000/06/28 16:47:02 loic E
 #include "gen_client_ext.h"
 #include "rpc_client_ext.h"
 #endif
+#undef __lock_init
 
-static void __lock_dump_locker __P((DB_LOCKTAB *, DB_LOCKER *, FILE *));
-static void __lock_dump_object __P((DB_LOCKTAB *, DB_LOCKOBJ *, FILE *));
+static void __lock_dump_locker (DB_LOCKTAB *, DB_LOCKER *, FILE *);
+static void __lock_dump_object (DB_LOCKTAB *, DB_LOCKOBJ *, FILE *);
 static const char *
 	    __lock_dump_status __P((db_status_t));
+
 static int  __lock_init __P((DB_ENV *, DB_LOCKTAB *));
 static size_t
 	    __lock_region_size __P((DB_ENV *));
@@ -245,7 +247,7 @@ err:	if (lt->reginfo.addr != NULL) {
 	}
 	CDB___os_free(lt, sizeof(*lt));
 	return (ret);
-}
+};
 
 /*
  * __lock_init --
