@@ -2,12 +2,12 @@
 // WordCursorOne.cc
 //
 // Part of the ht://Dig package   <http://www.htdig.org/>
-// Copyright (c) 1999, 2000 The ht://Dig Group
+// Copyright (c) 1999, 2000, 2001 The ht://Dig Group
 // For copyright details, see the file COPYING in your distribution
 // or the GNU General Public License version 2 or later
 // <http://www.gnu.org/copyleft/gpl.html>
 //
-// $Id: WordCursorOne.cc,v 1.7 2000/11/09 07:49:26 loic Exp $
+// $Id: WordCursorOne.cc,v 1.10 2001/06/29 14:14:08 loic Exp $
 //
 
 #ifdef HAVE_CONFIG_H
@@ -160,7 +160,7 @@ WordCursorOne::Walk()
   int ret1;
   if((ret1 = WalkFinish()) != OK) return ret1;
 
-  return ret == WORD_WALK_ATEND ? OK : NOTOK;
+  return (ret & WORD_WALK_RESULT_MASK) == WORD_WALK_ATEND ? OK : NOTOK;
 }
 
 int 
@@ -281,6 +281,7 @@ WordCursorOne::WalkNextStep()
     if((error = cursor->Get(key, data, cursor_get_flags)) != 0) {
       if(error == DB_NOTFOUND) {
 	if(words->verbose) fprintf(stderr, "WordCursorOne::WalkNextStep: looking for next %s, no more matches\n", (char*)searchKey.Get());
+	found.Clear();
 	return (status = WORD_WALK_ATEND);
       } else {
 	return WORD_WALK_GET_FAILED;
@@ -297,6 +298,8 @@ WordCursorOne::WalkNextStep()
 
   if(words->Dead()->Exists(found.Key()))
     return WORD_WALK_NOMATCH_FAILED;
+  if(WalkNextExclude(found.Key()))
+    return WORD_WALK_NOMATCH_FAILED;
 
   if(traceRes) traceRes->Add(new WordReference(found));
 
@@ -319,7 +322,7 @@ WordCursorOne::WalkNextStep()
     if(!prefixKey.Empty() &&
        !prefixKey.Equal(found.Key()))	{
       if(words->verbose) fprintf(stderr, "WordCursorOne::WalkNextStep: looking for next %s, no more matches because found a key that is greater than searchKey\n", (char*)searchKey.Get());
-      return (status = WORD_WALK_ATEND);
+      return (status = WORD_WALK_ATEND|WORD_WALK_ATEND_NOMATCH);
     }
 
     //
@@ -328,14 +331,14 @@ WordCursorOne::WalkNextStep()
     if(!searchKeyIsSameAsPrefix && 
        !searchKey.Equal(found.Key()))	{
       int ret;
-      switch((ret = SkipUselessSequentialWalking())) {
+      switch((ret = SkipUselessSequentialWalking()) & WORD_WALK_RESULT_MASK) {
       case OK:
 	if(words->verbose > 1) fprintf(stderr, "WordCursorOne::WalkNextStep: looking for next %s, false match jump to %s\n", (char*)searchKey.Get(), (char*)found.Get());
 	return WORD_WALK_NOMATCH_FAILED;
 	break;
       case WORD_WALK_ATEND:
 	if(words->verbose) fprintf(stderr, "WordCursorOne::WalkNextStep: looking for next %s, no more matches according to SkipUselessSequentialWalking\n", (char*)searchKey.Get());
-	return (status = WORD_WALK_ATEND);
+	return status = ret;
 	break;
       default:
 	fprintf(stderr, "WordCursorOne::WalkNextStep: SkipUselessSequentialWalking failed %d\n", ret);
@@ -359,7 +362,7 @@ WordCursorOne::WalkNextStep()
     //
     if(ret != OK) {
       if(words->verbose) fprintf(stderr, "WordCursorOne::WalkNextStep: callback returned NOTOK");
-      return WORD_WALK_CALLBACK_FAILED|(status = WORD_WALK_ATEND);
+      return (status = WORD_WALK_CALLBACK_FAILED|WORD_WALK_ATEND);
     }
   }
 
@@ -539,11 +542,15 @@ WordCursorOne::Seek(const WordKey& patch)
   
   int i;
   //
-  // Leave the most significant fields untouched
+  // Leave the most significant fields untouched if they are
+  // already set, or set them to zero if they are not.
   //
-  for(i = WORD_KEY_WORD + 1; i < nfields; i++)
+  for(i = WORD_KEY_WORD + 1; i < nfields; i++) {
     if(patch.IsDefined(i))
       break;
+    else if(!pos.IsDefined(i))
+      pos.Set(i, 0);
+  }
   //
   // From the first value set in the patch to the end
   // override.
@@ -556,7 +563,7 @@ WordCursorOne::Seek(const WordKey& patch)
   }
 
   if(!pos.Filled()) {
-    fprintf(stderr, "WordCursorOne::Seek: only make sense if the resulting key is fully defined\n");
+    fprintf(stderr, "WordCursorOne::Seek: only makes sense if the resulting key is fully defined\n");
     return NOTOK;
   }
 
