@@ -5,7 +5,7 @@
 // or the GNU General Public License version 2 or later
 // <http://www.gnu.org/copyleft/gpl.html>
 //
-// $Id: WordKeySemantic.h,v 1.6 2001/06/29 14:14:08 loic Exp $
+// $Id: WordKeySemantic.h,v 1.7 2001/07/20 10:37:53 loic Exp $
 //
 // ************************* Document definition implementation ***********
 
@@ -127,7 +127,7 @@ public:
   // method of WordKey. <b>uniq</b> is the WordKey position at which the 
   // increment starts.
   //
-  void DocumentNext(WordKey& key, int uniq);
+  void DocumentNext(WordKey& key, int use_uniq);
   //-
   // Compare the document fields defined in both <b>a</b> and <b>b</b>
   // and return the difference a - b, as in strcmp. If all document
