@@ -7,7 +7,7 @@
 // or the GNU General Public License version 2 or later
 // <http://www.gnu.org/copyleft/gpl.html>
 //
-// $Id: WordResults.cc,v 1.4 2001/07/20 10:37:53 loic Exp $
+// $Id: WordResults.cc,v 1.5 2001/08/31 14:06:04 loic Exp $
 //
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -650,6 +650,64 @@ int WordResults::GetContext(String& context_in) const
   return OK;
 }
 
+int WordResults::PutMatchesTotal(unsigned int matches_total)
+{
+  if(verbose)
+    fprintf(stderr, "WordResults::PutMatchesTotal: %d\n", matches_total);
+  
+  DBT rkey;
+  DBT rdata;
+  int error;
+
+  memset((void*)&rkey, '\0', sizeof(DBT));
+  rkey.data = (void*)"matches_total";
+  rkey.size = strlen((char*)rkey.data);
+
+  memset((void*)&rdata, '\0', sizeof(DBT));
+  rdata.data = (void*)&matches_total;
+  rdata.size = sizeof(unsigned int);
+
+  if((error = variables_cursor->c_put(variables_cursor, &rkey, &rdata, DB_KEYFIRST)) != 0) {
+    fprintf(stderr, "WordResults::PutMatchesTotal: variables_cursor->c_put(%d) failed: %s\n", matches_total, CDB_db_strerror(error));
+    return NOTOK;
+  }
+
+  return OK;
+}
+
+int WordResults::GetMatchesTotal(unsigned int& matches_total) const
+{
+  if(verbose)
+    fprintf(stderr, "WordResults::GetMatchesTotal:\n");
+
+  matches_total = 0;
+
+  DBT rkey;
+  DBT rdata;
+
+  memset((void*)&rkey, '\0', sizeof(DBT));
+  rkey.data = (void*)"matches_total";
+  rkey.size = strlen((char*)rkey.data);
+
+  memset((void*)&rdata, '\0', sizeof(DBT));
+
+  int error;
+  if((error = variables_cursor->c_get(variables_cursor, &rkey, &rdata, DB_SET)) != 0) {
+    if(error != DB_NOTFOUND) {
+      fprintf(stderr, "WordResults::GetMatchesTotal variables_cursor->c_get(matches_total) failed: %s\n", CDB_db_strerror(error));
+      return NOTOK;
+    }
+  }
+
+  if(error == 0) {
+    memcpy((char*)&matches_total, (char*)rdata.data, sizeof(unsigned int));
+  } else {
+    matches_total = 0;
+  }
+
+  return OK;
+}
+
 int WordResults::Count(unsigned int& count) const
 {
   int error;
